@@ -45,71 +45,7 @@
 #include <termios.h>
 #endif
 
-#if defined(HAVE_LIBREADLINE)
-
-#include <readline/readline.h>
-#include <readline/history.h>
-
-char * command_generator( const char *text, int state)
-{
-    static int list_index, len;
-    char *name;
-
-    if (!state)
-    {
-        list_index = 0;
-        len = strlen(text);
-    }
-
-    while ( ( name = command_keywords[list_index].word ) )
-    {
-        list_index++;
-
-        if ( strncmp(name, text, len) == 0 )
-        {
-            char *copy = malloc( strlen(name) + 1);
-            osi_strlcpy( copy, name, strlen(name)+1 );
-            return copy;
-        }
-    }
-
-    return NULL;
-}
-
-
-char ** fileman_completion( const char *text, int start, int end )
-{
-    char **matches = NULL;
-
-    if ( start == 0 )
-    {
-        matches = rl_completion_matches( text, command_generator );
-    }
-
-    return matches;
-}
-
-int get_user_input( char *buffer, int buffer_size )
-{
-    char *line = readline("");
-    rl_attempted_completion_function = fileman_completion;
-
-    if ( line )
-    {
-        osi_strlcpy( buffer, line, buffer_size );
-
-        if ( *line )
-        {
-            add_history( line );
-        }
-    }
-
-    return strlen( buffer );
-}
-
-
-
-#elif defined(FANCY_CLI)
+#if defined(FANCY_CLI)
 
 #ifdef WIN32
 #define KEY_CODE_ESC                224
@@ -296,6 +232,68 @@ start:
     return strlen( buffer );
 }
 
+#elif defined(HAVE_LIBREADLINE)
+
+#include <readline/readline.h>
+#include <readline/history.h>
+
+char * command_generator( const char *text, int state)
+{
+    static int list_index, len;
+    char *name;
+
+    if (!state)
+    {
+        list_index = 0;
+        len = strlen(text);
+    }
+
+    while ( ( name = command_keywords[list_index].word ) )
+    {
+        list_index++;
+
+        if ( strncmp(name, text, len) == 0 )
+        {
+            char *copy = malloc( strlen(name) + 1);
+            osi_strlcpy( copy, name, strlen(name)+1 );
+            return copy;
+        }
+    }
+
+    return NULL;
+}
+
+
+char ** fileman_completion( const char *text, int start, int end )
+{
+    char **matches = NULL;
+
+    if ( start == 0 )
+    {
+        matches = rl_completion_matches( text, command_generator );
+    }
+
+    return matches;
+}
+
+int get_user_input( char *buffer, int buffer_size )
+{
+    char *line = readline("");
+    rl_attempted_completion_function = fileman_completion;
+
+    if ( line )
+    {
+        osi_strlcpy( buffer, line, buffer_size );
+
+        if ( *line )
+        {
+            add_history( line );
+        }
+    }
+
+    return strlen( buffer );
+}
+
 #else
 
 /* NO FANCY CLI, AND NO READLINE */
