@@ -1,7 +1,7 @@
 
-/*****************************************************************************
+/******************************************************************************
 **
-**  Copyright (C) 2001  - the shmoo group -
+**  Copyright (C) 2005 Brian Wotring.
 **
 **  This program is free software; you can redistribute it and/or
 **  modify it, however, you cannot sell it.
@@ -11,15 +11,15 @@
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 **
 **  You should have received a copy of the license attached to the
-**  use of this software.  If not, visit www.shmoo.com/osiris for
-**  details.
+**  use of this software.  If not, view a current copy of the license
+**  file here:
 **
-*****************************************************************************/
+**      http://www.hostintegrity.com/osiris/LICENSE
+**
+******************************************************************************/
 
 /*****************************************************************************
 **
-**    The Shmoo Group (TSG)
-**
 **    File:      configuration.c
 **    Author:    Brian Wotring
 **
@@ -100,8 +100,15 @@ static struct keywords action_keywords[] =
 static struct keywords hash_keywords[] =
 {
     { "md5", HASH_MD5 },
+
     { "sha", HASH_SHA },
+    { "sha1", HASH_SHA },
+    { "sha-1", HASH_SHA },
+
     { "ripemd", HASH_RIPEMD },
+    { "ripemd-160", HASH_RIPEMD },
+    { "ripemd160", HASH_RIPEMD },
+
     { NULL, 0 }
 };
 
@@ -110,7 +117,11 @@ static char * valid_hash_values[] =
 {
     "md5",
     "sha",
+    "sha1",
+    "sha-1",
     "ripemd",
+    "ripemd160",
+    "ripemd-160",
     NULL
 };
 
