@@ -1,7 +1,7 @@
 
 /******************************************************************************
 **
-**  Copyright (C) 2001  - the shmoo group -
+**  Copyright (C) 2005 Brian Wotring.
 **
 **  This program is free software; you can redistribute it and/or
 **  modify it, however, you cannot sell it.
@@ -11,15 +11,15 @@
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 **
 **  You should have received a copy of the license attached to the
-**  use of this software.  If not, visit www.shmoo.com/osiris for
-**  details.
+**  use of this software.  If not, view a current copy of the license
+**  file here:
+**
+**      http://www.hostintegrity.com/osiris/LICENSE
 **
 ******************************************************************************/
 
 /******************************************************************************
 **
-**    The Shmoo Group (TSG)
-**
 **    File:      filter.c
 **    Author:    Brian Wotring
 **
@@ -46,7 +46,7 @@ static struct keywords filter_keywords[] =
 {
     { "sticky", FILTER_TYPE_STICKY },
     { "suid", FILTER_TYPE_SUID },
-    { "guid", FILTER_TYPE_GUID },
+    { "sgid", FILTER_TYPE_SGID },
     { "executable", FILTER_TYPE_EXECUTABLE },
     { "perl", FILTER_TYPE_PERL },
     { "python", FILTER_TYPE_PYTHON },
@@ -99,8 +99,8 @@ int setup_filter_function( OSI_FILTER *action_filter, int type )
             action_filter->perform = filter_suid;
             break;
 
-        case FILTER_TYPE_GUID:
-            action_filter->perform = filter_guid;
+        case FILTER_TYPE_SGID:
+            action_filter->perform = filter_sgid;
             break;
 
         case FILTER_TYPE_EXECUTABLE:
