@@ -59,6 +59,10 @@
 
 #endif /* END NOT WIN32 */
 
+#ifdef HAVE_CTYPE_H
+#include <ctype.h>
+#endif
+
 #include "scanner.h"
 #include "logging.h"
 
@@ -82,6 +86,7 @@ HANDLE stop_scan_event  = NULL;
 #else
 const int SYSLOG_FACILITY     = LOG_DAEMON;
 const int SYSLOG_OPTIONS      = ( LOG_NDELAY | LOG_PID );
+char pid_file[MAX_PATH_LENGTH] = "/var/run/osirisd.pid";
 #endif
 
 /* server state data. */
@@ -256,12 +261,25 @@ void parse_arguments( int argument_count, char *argument_list[] )
                   strcmp( argument_list[count], "-p" ) == 0 ) &&
                 ( count < ( argument_count - 1 ) ) )
         {
+            int i;
             count++;
+
+            /* sanity checks on port number */
+
+            for( i = 0; i < strlen( argument_list[count] ); i++ )
+            {
+                if ( isdigit(argument_list[count][i] ) == 0 )
+                {
+                    fprintf( stderr, "Invalid listen port!\n" );
+                    halt(0);
+                }
+            }
+
             listen_port = atoi( argument_list[count] );
 
-            if( listen_port < 0 || listen_port > 65535 )
+            if ( listen_port <= 0 || listen_port > 65535 )
             {
-                fprintf( stderr, "Invalid listen port!" );
+                fprintf( stderr, "Invalid listen port!\n" );
                 halt(0);
             }
         }
@@ -292,6 +310,14 @@ void parse_arguments( int argument_count, char *argument_list[] )
             }
         }
 
+        else if ( ( strcmp( argument_list[count], "-e" ) == 0 ||
+                    strcmp( argument_list[count], "--pid" ) == 0 ) &&
+                 ( count < ( argument_count - 1 ) ) )
+        {
+            count++;
+            osi_strlcpy( pid_file, argument_list[count], sizeof(pid_file) );
+        }
+
         else if( ( strncmp( argument_list[count], "-n", 2 ) == 0 ) )
         {
             if( strlen( argument_list[count] ) > 2 )
@@ -2240,9 +2266,11 @@ void print_usage()
     osi_print_stdout( "Osiris Scan Agent - Version %s\n", OSIRIS_VERSION );
 
 #ifndef WIN32
-    osi_print_stdout( "usage: osirisd [-r <path>] [-p <port>] [-n <level>] [-q] [-h]\n" );
-    fprintf( stdout,  "  -n <level>  " );
+    osi_print_stdout( "usage: osirisd [-r <path>] [-e <file>] [-p <port>] [-n <level>] [-q] [-h]\n" );
+    fprintf( stdout,  "  -n <level>   " );
     osi_print_stdout( "use specified nice level." );
+    fprintf( stdout,  "  -e <file>    " );
+    osi_print_stdout( "pid file location (default:/var/run/osirisd.pid)" );
 #else
     osi_print_stdout( "usage: osirisd [-i|-u] [-p <port>] [-h] [-d] [-q]\n" );
     fprintf( stdout,  "  -i          " );
@@ -2253,15 +2281,15 @@ void print_usage()
     osi_print_stdout( "run this application as a daemon, not a service." );
 #endif
 
-    fprintf( stdout, "  -p <port>   ");
+    fprintf( stdout, "  -p <port>    ");
     osi_print_stdout( "specify an alternate listen port (default:%d)",
                       DEFAULT_SCAN_AGENT_PORT );
 
-    fprintf( stdout, "  -q          " );
+    fprintf( stdout, "  -q           " );
     osi_print_stdout( "quiet mode, agent produces no log messages." );
-    fprintf( stdout, "  -r          " );
+    fprintf( stdout, "  -r           " );
     osi_print_stdout( "specify alternate root directory containing root cert.");
-    fprintf( stdout, "  -h          " );
+    fprintf( stdout, "  -h           " );
     osi_print_stdout( "print this usage statement." );
     osi_print_stdout( "" );
 }
