@@ -80,6 +80,10 @@ static volatile osi_atomic_t received_sigint = 0;
 extern pid_t child_pid;
 extern int rootpriv_pipe[2];      /* socketpair used for rootpriv comm.  */
 
+#ifndef WIN32
+extern char pid_file[MAX_PATH_LENGTH];
+#endif
+
 #define INCOMING_ROOT_REQUEST() ( FD_ISSET( rootpriv_pipe[1], &root_read_set ) )
 
 
@@ -290,7 +294,7 @@ void setup_signals()
 
 void setup_pidfile()
 {
-    FILE *pidfile = fopen( PIDFILE, "wb" );
+    FILE *pidfile = fopen( pid_file, "wb" );
 
     if( pidfile != NULL )
     {
@@ -317,7 +321,7 @@ void handle_signals()
 
     if( received_sigterm || received_sigint )
     {
-        unlink( PIDFILE );
+        unlink( pid_file);
 
         /* kill child daemon. */
 
