@@ -1,6 +1,8 @@
 
 /******************************************************************************
 **
+**  Copyright (C) 2005 Brian Wotring.
+**
 **  This program is free software; you can redistribute it and/or
 **  modify it, however, you cannot sell it.
 **
@@ -9,8 +11,10 @@
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 **
 **  You should have received a copy of the license attached to the
-**  use of this software.  If not, visit www.shmoo.com/osiris for
-**  details.
+**  use of this software.  If not, view a current copy of the license
+**  file here:
+**
+**      http://www.hostintegrity.com/osiris/LICENSE
 **
 ******************************************************************************/
 
@@ -27,6 +31,38 @@
 #ifndef MD_COMPARE_H
 #define MD_COMPARE_H
 
+typedef enum
+{
+    /* UNIX 1 */
+
+    ATTR_CHECKSUM      = 1 << 0,
+    ATTR_DEVICE        = 1 << 1,
+    ATTR_INODE         = 1 << 2,
+    ATTR_PERMISSIONS   = 1 << 3,
+    ATTR_LINKS         = 1 << 4,
+    ATTR_UID           = 1 << 5,
+    ATTR_GID           = 1 << 6,
+    ATTR_MTIME         = 1 << 7,
+    ATTR_ATIME         = 1 << 8,
+    ATTR_CTIME         = 1 << 9,
+    ATTR_DEVICE_TYPE   = 1 << 10,
+    ATTR_BYTES         = 1 << 11,
+    ATTR_BLOCKS        = 1 << 12,
+    ATTR_BLOCK_SIZE    = 1 << 13,
+
+    /* WINNT */
+
+    ATTR_OWNER_SID       = 1 << 14,
+    ATTR_GROUP_SID       = 1 << 15,
+    ATTR_WIN32_FILE      = 1 << 16,
+
+    /* new and missing. */
+
+    ATTR_NEW           = 1 << 17,
+    ATTR_MISSING       = 1 << 18
+
+} OSI_ATTR_MASK;
+
 
 #define CMP_MASK_DEFAULT  ( ATTR_CHECKSUM | ATTR_DEVICE | ATTR_INODE |\
                             ATTR_PERMISSIONS | ATTR_LINKS | ATTR_UID |\
@@ -46,7 +82,7 @@ typedef struct OSI_DB_CTX
     char db2_name[MAX_HOSTNAME_LENGTH];
 
     char config_name[MAX_HOSTNAME_LENGTH];
-    
+
     OSI_ATTR_MASK compare_mask;
     osi_bool use_system_log;
 
@@ -57,7 +93,6 @@ typedef struct OSI_DB_CTX
     /* used to note what changed for a file. */
 
     OSI_ATTR_MASK changed_mask;
-    osi_bool change_was_filtered;
 
     /* compare statistics counters. */
 
