@@ -1,6 +1,8 @@
 
 /******************************************************************************
 **
+**  Copyright (C) 2005 Brian Wotring.
+**
 **  This program is free software; you can redistribute it and/or
 **  modify it, however, you cannot sell it.
 **
@@ -9,8 +11,10 @@
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 **
 **  You should have received a copy of the license attached to the
-**  use of this software.  If not, visit www.shmoo.com/osiris for
-**  details.
+**  use of this software.  If not, view a current copy of the license
+**  file here:
+**
+**      http://www.hostintegrity.com/osiris/LICENSE
 **
 ******************************************************************************/
 
@@ -104,9 +108,6 @@ void osi_set_host_defaults( OSI_HOST *host )
         host->schedule_period = 0;
 
         host->port = DEFAULT_SCAN_AGENT_PORT;
-        
-        memset( host->session_key, 0, sizeof( host->session_key ) );
-        memset( host->base_db, 0, sizeof( host->base_db ) );
     }
 }
 
@@ -316,12 +317,12 @@ OSI_HOST * osi_read_host( const char *name )
         osi_strlcpy( host->base_db, host_brief.base_db,
                      sizeof( host->base_db ) );
 
+        osi_strlcpy( host->config, host_brief.config,
+                     sizeof( host->config) );
+
         osi_strlcpy( host->notify_email, host_brief.notify_email,
                      sizeof( host->notify_email ) );
 
-        osi_strlcpy( host->config, host_brief.config,
-                     sizeof( host->config ) );
-            
         host->file_log_enabled  = host_brief.file_log_enabled; 
         host->db_flags          = host_brief.db_flags;
 
@@ -440,12 +441,12 @@ osi_bool osi_write_host( OSI_HOST *host )
     osi_strlcpy( host_brief.base_db, host->base_db,
                  sizeof( host_brief.base_db ) );
 
+    osi_strlcpy( host_brief.config, host->config,
+                 sizeof( host_brief.config) );
+
     osi_strlcpy( host_brief.notify_email, host->notify_email,
                  sizeof( host_brief.notify_email ) );
 
-    osi_strlcpy( host_brief.config, host->config,
-                 sizeof( host_brief.config ) );
-       
     host_brief.file_log_enabled  = host->file_log_enabled; 
     host_brief.db_flags          = host->db_flags;
 
