@@ -1,6 +1,8 @@
 
 /******************************************************************************
 **
+**  Copyright (C) 2005 Brian Wotring.
+**
 **  This program is free software; you can redistribute it and/or
 **  modify it, however, you cannot sell it.
 **
@@ -9,8 +11,10 @@
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 **
 **  You should have received a copy of the license attached to the
-**  use of this software.  If not, visit www.shmoo.com/osiris for
-**  details.
+**  use of this software.  If not, view a current copy of the license
+**  file here:
+**
+**      http://www.hostintegrity.com/osiris/LICENSE
 **
 ******************************************************************************/
 
@@ -27,16 +31,39 @@
 #ifndef MD_NOTIFY_H_
 #define MD_NOTIFY_H_
 
-void md_notify( const char *email, OSI_DB_CTX *context,osi_bool show_url);
+#define CTX_PAYLOAD_LENGTH 8192
+#define CTX_HEADERS_LENGTH 4096
 
-void md_notify_session_rekey( const char *host, const char *email );
+#define NOTIFY_TYPE_TEST            1
+#define NOTIFY_TYPE_REKEY           2
+#define NOTIFY_TYPE_LOG             3
+#define NOTIFY_TYPE_SCHEDULE_FAIL   4
+#define NOTIFY_TYPE_REPORT          5
 
-void md_notify_scan_failed( const char *host,
-                                   const char *email,
-                                   unsigned long scheduled_time,
-                                   const char *message );
+/* all the random crap possibly used when sending a notification. */
 
-osi_bool  md_notify_send_test( const char *email, OSI_ERROR *error );
+typedef struct MD_NOTIFY_CTX
+{
+    int type;
+    int diff_count;
+
+    char *host;
+    char *email;
+    char *message;
+    char *filename;
+    char *db_name;
+
+    char hostname[MAX_HOSTNAME_LENGTH];
+    char headers[CTX_HEADERS_LENGTH];
+    char payload[CTX_PAYLOAD_LENGTH];
+
+    osi_bool show_url;
+    OSI_ERROR error;
+
+} MD_NOTIFY_CTX;
+
+void md_notify_init( MD_NOTIFY_CTX *ctx, int type );
+void md_notify( MD_NOTIFY_CTX *ctx );
 
 #endif
 
