@@ -1,6 +1,8 @@
 
 /******************************************************************************
 **
+**  Copyright (C) 2005 Brian Wotring.
+**
 **  This program is free software; you can redistribute it and/or
 **  modify it, however, you cannot sell it.
 **
@@ -9,8 +11,10 @@
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 **
 **  You should have received a copy of the license attached to the
-**  use of this software.  If not, visit www.shmoo.com/osiris for
-**  details.
+**  use of this software.  If not, view a current copy of the license
+**  file here:
+**
+**      http://www.hostintegrity.com/osiris/LICENSE
 **
 ******************************************************************************/
 
@@ -40,6 +44,10 @@
 #include "md_notify.h"
 #include "md_utilities.h"
 
+#ifdef HAVE_SYS_WAIT_H
+#include <sys/wait.h>
+#endif
+
 #include "logging.h"
 
 extern OSI_MANAGEMENT_CONFIG *config;
@@ -425,6 +433,7 @@ osi_bool perform_session_key_negotiation( SSL *ssl, OSI_HOST *host )
 
         if( strlen( host->session_key ) > 0 )
         {
+            MD_NOTIFY_CTX ctx;
             char *email = config->notify_email;
 
             if( strlen( host->notify_email ) )
@@ -435,24 +444,20 @@ osi_bool perform_session_key_negotiation( SSL *ssl, OSI_HOST *host )
             if( ( host->notify_enabled ) &&
                 ( host->notify_flags & OSI_NOTIFY_AGENT_REKEY ) )
             {
-                md_notify_session_rekey( host->name, email );
+                md_notify_init( &ctx, NOTIFY_TYPE_REKEY );
+                ctx.host = host->name;
+                ctx.email = email;
+                md_notify( &ctx );
             }
 
-            /* always notify the admin. */
-
-            if ( strlen( config->admin_email ) > 0 )
-            {
-                md_notify_session_rekey( host->name,config->admin_email );
-            }
-
-            log_warning( LOG_ID_SESSION_KEY_LOST, host->host,
+            log_warning( LOG_ID_SESSION_KEY_LOST, host->name,
              "scan agent lost its session key, most likely it was restarted." );
         }
 
         if( osi_ssl_write_message( &message, ssl ) == MESSAGE_OK )
         {
             unsigned char checksum[HOST_SESSION_KEY_HASH_LENGTH];
-            log_info( LOG_ID_SESSION_KEY_NEW, host->host,
+            log_info( LOG_ID_SESSION_KEY_NEW, host->name,
                       "new session key assigned." );
 
             /* now save it locally in the host's config file, we only */
@@ -461,7 +466,7 @@ osi_bool perform_session_key_negotiation( SSL *ssl, OSI_HOST *host )
             if( generate_session_key_hash( key, HOST_SESSION_KEY_LENGTH,
                                        checksum, sizeof( checksum ) ) == FALSE )
             {
-                log_error( LOG_ID_SESSION_KEY_FAILURE, host->host,
+                log_error( LOG_ID_SESSION_KEY_FAILURE, host->name,
                            "unable to hash new session key." );
 
                 return FALSE;
@@ -477,7 +482,7 @@ osi_bool perform_session_key_negotiation( SSL *ssl, OSI_HOST *host )
 
         else
         {
-            log_error( LOG_ID_SESSION_KEY_FAILURE, host->host, 
+            log_error( LOG_ID_SESSION_KEY_FAILURE, host->name, 
                        "failed to send session key to scanning daemon." );
         }
     }
@@ -628,12 +633,12 @@ int osi_host_push_base_db_config( const char *host_name )
     OSI_HOST *host;
     OSI_DATABASE_BRIEF db_brief;
 
-    if( host_name == NULL )
+    if ( host_name == NULL )
     {
         return result;
     }
 
-    if( ( host = osi_read_host( host_name ) ) == NULL )
+    if ( ( host = osi_read_host( host_name ) ) == NULL )
     {
         return OSI_ERROR_HOST_DOES_NOT_EXIST;
     }
@@ -663,3 +668,71 @@ int osi_host_push_base_db_config( const char *host_name )
     return result;
 }
 
+#ifndef WIN32
+
+int launch_log_application( int *pipes )
+{
+    pid_t pid;
+
+    if ( !pipes )
+    {
+        return -1;
+    }
+
+    pipes[0] = -1;
+    pipes[1] = -1;
+
+    if ( config->notify_app == NULL || strlen(config->notify_app) == 0 )
+    {
+        return -1;
+    }
+
+    if ( pipe(pipes) != 0 )
+    {
+        log_error( LOG_ID_LOG_APP_FAILURE, NULL, "unable to create pipe!" );
+        return -1;
+    }
+
+    /* child handles the actual notification. */
+
+    switch( pid=fork() )
+    {
+        case -1:
+
+            log_error( LOG_ID_LOG_APP_FAILURE, NULL, "unable to fork!" );
+            return -1;
+
+        /* child. */
+
+        case 0 :
+
+            dup2( pipes[0], 0 );
+            close( pipes[1] );
+            execl( config->notify_app, config->notify_app, NULL );
+            exit(0);
+
+        /* parent. */
+
+        default:
+
+            close( pipes[0] );
+            setvbuf( stdout,(char*)NULL, _IONBF, 0 );
+    }
+
+    return (int)pid;
+}
+
+void close_log_application( int *pipes )
+{
+    int status = 0;
+
+    if ( !pipes )
+    {
+        return;
+    }
+
+    close(pipes[1]);
+    wait( &status );
+}
+#endif
+
