@@ -67,6 +67,11 @@
 
 #include "osirismd.h"
 
+
+#ifndef WIN32
+char pid_file[MAX_PATH_LENGTH] = "";
+#endif
+
 static void genrsa_cb( int p, int n, void *arg );
 extern osi_bool name_regex( const char *name, const char *pattern );
 
@@ -121,6 +126,7 @@ THREAD_FUNCTION_TYPE run( void *unused )
     start_log_application();
     start_scheduler();
     start_servers();
+    setup_pidfile();
 
     md_auth_load_database();
 
@@ -738,6 +744,14 @@ void parse_arguments( int argument_count, char *argument_list[] )
             }
         }
 
+        else if ( ( strcmp( argument_list[count], "-e" ) == 0 ||
+                    strcmp( argument_list[count], "--pid" ) == 0 ) &&
+                 ( count < ( argument_count - 1 ) ) )
+        {
+            count++;
+            osi_strlcpy( pid_file, argument_list[count], sizeof(pid_file) );
+        }
+
         else if( strcmp( argument_list[count], "--help" ) == 0 ||
                  strcmp( argument_list[count], "-h" ) == 0 )
         {
@@ -864,16 +878,19 @@ void print_usage()
 #ifdef WIN32
     osi_print_stdout( "usage: osirismd [-r <directory>] [-f <file>] [-d] [-h] | [-u|-i]\n" );
 #else
-    osi_print_stdout( "usage: osirismd [-r <directory>] [-f <file>] [-h]\n" );
+    osi_print_stdout( "usage: osirismd [-r <directory>] [-f <file>] [-e <file>] [-h]\n" );
 #endif
-    osi_print_stdout( "  -r directory   : specify alternate directory for certs and hosts." );
-    osi_print_stdout( "  -f file        : specify alternate configuration file." );
-    osi_print_stdout( "  -h             : this usage statement." );
+    osi_print_stdout( "  -r <directory>  : specify alternate directory for certs and hosts." );
+    osi_print_stdout( "  -f <file>       : specify alternate configuration file." );
+#ifndef WIN32
+    osi_print_stdout( "  -e <file>       : specify pid file (default:none)." );
+#endif
+    osi_print_stdout( "  -h              : this usage statement." );
 
 #ifdef WIN32
-    osi_print_stdout( "  -i             : install as a windows service on local machine." );
-    osi_print_stdout( "  -u             : uninstall windows service from local machine." );
-    osi_print_stdout( "  -d             : run this application as a normal daemon, not a service." );
+    osi_print_stdout( "  -i              : install as a windows service on local machine." );
+    osi_print_stdout( "  -u              : uninstall windows service from local machine." );
+    osi_print_stdout( "  -d              : run this application as a normal daemon, not a service." );
 #endif
 
    	osi_print_stdout( "" );
@@ -1829,6 +1846,26 @@ void signal_restart_needed()
     osi_write( restart_pipe[1], "x", 1 );
 }
 
+void setup_pidfile()
+{
+#ifndef WIN32
+    FILE *pidfile;
+
+    if ( strlen( pid_file ) == 0 )
+    {
+        return;
+    }
+
+    pidfile = fopen( pid_file, "wb" );
+
+    if( pidfile != NULL )
+    {
+        fprintf( pidfile, "%ld\n", (long)getpid() );
+        fclose( pidfile );
+    }
+#endif
+}
+
 
 /******************************************************************************
 **
